==> devavrata_free_bare-6.x-1.1.tar.gz: devavrata_free_bare/devavrata_core/devavrata_free_bare_settings.php <==
<?php
/***********************************************************
 * Devavrata Core Theme for Drupal - Free
 * A WebTheming.com Stylesheet Production
 * Created by Daniel Honrade
 * for paid technical support: mail@danielhonrade.com
 * http://webtheming.com
 * http://danielhonrade.com
 ***********************************************************/
 
// Initialize theme settings
if (is_null(theme_get_setting('content_title_size'))) {  // Check settings
  global $theme_key;

  $defaults = array( 
   'content_column' => 'Default Style',
   'page_size' => '600px',
   'header_hide' => 'Show',
   'search_transfer' => 'No',
   'drop_cap' => 'No',
   'content_enlarge_button' => 'Show',
   'content_title_size' => '16px',
   'content_body_size' => '11px',
   'content_body_fonts' => 'Arial, Helvetica, sans-serif',
  );
  // Get default theme settings.
  $settings = theme_get_settings($theme_key);
  // Don't save the toggle_node_info_ variables.
  if (module_exists('node')) {
    foreach (node_get_types() as $type => $name) {
      unset($settings['toggle_node_info_' . $type]);
    }
  }
  // Save default theme settings.
  variable_set(
    str_replace('/', '_', 'theme_'. $theme_key .'_settings'),
    array_merge($defaults, $settings)
  );
  // Force refresh of Drupal internals.
  theme_get_setting('', TRUE);
}

/* Devavrata Text Features
 * content title size
 * content body size
 */
function devavrata_free_bare_text_feature($content_title_size, $content_body_size) {
	if($content_title_size || $content_body_size) {
		$body_style = '<style type="text/css" media="screen">';
		switch($content_title_size) {
			case 0: $body_style .= ''; break;
			case 1: $body_style .= '#content-main h2, #content-elements h2 { font-size: 18px; }'; break;
			case 2: $body_style .= '#content-main h2, #content-elements h2 { font-size: 21px; }'; break;		
			case 3: $body_style .= '#content-main h2, #content-elements h2 { font-size: 25px; }'; break;
			default: $body_style .= '#content-main h2, #content-elements h2 { font-size: 16px; }'; break;
		}
		switch($content_body_size) {
			case 0: $body_style .= ''; break;
			case 1: $body_style .= '#content-main .content { font-size: 12px; 	line-height: 16px;}'; break;
			case 2: $body_style .= '#content-main .content { font-size: 13px; 	line-height: 18px;}'; break;		
			case 3: $body_style .= '#content-main .content { font-size: 14px; 	line-height: 20px;}'; break;
			default: $body_style .= '#content-main .content { font-size: 11px; 	line-height: 15px;}'; break;		
		}
		$body_style .= '</style>';
		return $body_style;
	}
}

==> devavrata_free_bare-6.x-1.3.tar.gz: devavrata_free_bare/devavrata_core/devavrata_free_bare_settings.php <==
<?php
/***********************************************************
 * Devavrata Core Theme for Drupal - Free
 * A WebTheming.com Stylesheet Production
 * Created by Daniel Honrade
 * for paid technical support: mail@danielhonrade.com
 * http://webtheming.com
 * http://danielhonrade.com
 ***********************************************************/
 
// Initialize theme settings
if (is_null(theme_get_setting('content_title_size'))) {  // Check settings
  global $theme_key;

  $defaults = array( 
   'content_column' => 'Default Style',
   'page_size' => '600px',
   'header_hide' => 'Show',
   'search_transfer' => 'No',
   'drop_cap' => 'No',
   'content_enlarge_button' => 'Show',
   'content_title_size' => '16px',
   'content_body_size' => '11px',
   'content_body_fonts' => 'Arial, Helvetica, sans-serif',
  );
  // Get default theme settings.
  $settings = theme_get_settings($theme_key);
  // Don't save the toggle_node_info_ variables.
  if (module_exists('node')) {
    foreach (node_get_types() as $type => $name) {
      unset($settings['toggle_node_info_' . $type]);
    }
  }
  // Save default theme settings.
  variable_set(
    str_replace('/', '_', 'theme_'. $theme_key .'_settings'),
    array_merge($defaults, $settings)
  );
  // Force refresh of Drupal internals.
  theme_get_setting('', TRUE);
}

/* Devavrata Text Features
 * content title size
 * content body size
 */
function devavrata_free_bare_text_feature($content_title_size, $content_body_size) {
	if($content_title_size || $content_body_size) {
		$body_style = '<style type="text/css" media="screen">';
		switch($content_title_size) {
			case 0: $body_style .= ''; break;
			case 1: $body_style .= '#content-region h2, #content-elements h2 { font-size: 18px; }'; break;
			case 2: $body_style .= '#content-region h2, #content-elements h2 { font-size: 21px; }'; break;		
			case 3: $body_style .= '#content-region h2, #content-elements h2 { font-size: 25px; }'; break;
			default: $body_style .= '#content-region h2, #content-elements h2 { font-size: 16px; }'; break;
		}
		switch($content_body_size) {
			case 0: $body_style .= ''; break;
			case 1: $body_style .= '#content-region .content { font-size: 12px; 	line-height: 16px;}'; break;
			case 2: $body_style .= '#content-region .content { font-size: 13px; 	line-height: 18px;}'; break;		
			case 3: $body_style .= '#content-region .content { font-size: 14px; 	line-height: 20px;}'; break;
			default: $body_style .= '#content-region .content { font-size: 11px; 	line-height: 15px;}'; break;		
		}
		$body_style .= '</style>';
		return $body_style;
	}
}
